package com.inspect.system.service;

import com.inspect.system.base.domain.SysOperateLog;

import java.util.List;

public interface ISysOperateLogService {
    int insertOperateLog(SysOperateLog operateLog);

    List<SysOperateLog> selectOperateLogList(SysOperateLog operateLog);

    int deleteOperateLogByIds(Long[] ids);

    SysOperateLog selectOperateLogById(Long id);

    void cleanOperateLog();

    List<SysOperateLog> selectAuditOperLogList(SysOperateLog operateLog);
}
